<?php

namespace Drupal\var_debugger\TwigExtension;

use Drupal\var_debugger\Utils\VarDebugger;
use Twig\Extension\AbstractExtension;
use Twig\TwigFunction;

/**
 * Adds a custom Twig function for debugging variables in templates.
 */
class VarDebuggerTwigExtension extends AbstractExtension {

  /**
   * Calls VarDebugger::log to debug a variable in a Twig template.
   *
   * @param mixed $var
   *   The variable to debug.
   * @param bool $exit
   *   If TRUE, stops script execution after logging.
   */
  public function varDebugger(mixed $var, bool $exit = FALSE) {
    return VarDebugger::log($var, $exit);
  }

  /**
   * Registers the `varDebugger` function for use in Twig templates.
   */
  public function getFunctions() {
    return [
      new TwigFunction('var_debugger', [$this, 'varDebugger']),
    ];
  }

}
